import React, { CSSProperties } from 'react';
import logImg from './assets/log.png';
import syncImg from './assets/sync.png';
import messagesImg from './assets/messages.png';
import logActiveImg from './assets/log.active.png';
import syncActiveImg from './assets/sync.active.png';
import messagesActiveImg from './assets/messages.active.png';
import styles from './indexLayout.less';
import classNames from 'classnames';
import ATooltip from '@/components/Tooltip';
import { Link } from 'umi';

const navList = [
  {
    pathname: '/sync',
    name: '同步任务',
    icon: syncImg,
    activeIcon: syncActiveImg,
  },
  {
    pathname: '/messages',
    name: '消息中心',
    icon: messagesImg,
    activeIcon: messagesActiveImg,
  },
  {
    pathname: '/log',
    name: '操作记录',
    icon: logImg,
    activeIcon: logActiveImg,
  },
];

interface NavProps {
  pathname: string;
  style?: CSSProperties;
  className?: string;
}

export default function Nav(props: NavProps) {
  const { pathname: currentPathname } = props;
  return (
    <div className={styles.nav}>
      {navList.map(({ pathname, name, icon, activeIcon }) => {
        const active = pathname.indexOf(currentPathname) === 0;
        return (
          <ATooltip key={name} title={name} placement="right">
            <Link
              className={classNames(
                styles.navItem,
                active ? styles.active : '',
              )}
              to={pathname}
            >
              <img src={active ? activeIcon : icon} alt="" />
            </Link>
          </ATooltip>
        );
      })}
    </div>
  );
}
